==> agent2d-0.1.0.tar.gz: agent2d-0.1.0/src/sample_player.h <==
// -*-c++-*-

/*
 *Copyright:

 Copyright (C) Hidehisa AKIYAMA

 This code is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This code is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this code; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *EndCopyright:
 */

/////////////////////////////////////////////////////////////////////

#ifndef AGENT2D_SAMPLE_PLAYER_H
#define AGENT2D__PLAYER_H

#include <rcsc/player/player_agent.h>

#include "strategy.h"

class SamplePlayer
    : public rcsc::PlayerAgent {
protected:
    Strategy M_strategy;

public:

    SamplePlayer();

    virtual
    ~SamplePlayer();

    /*!
      You can override this method.
      But strongly recommended to use PlayerAgent::doInit() in thid method.
    */
    virtual
    bool doInit( const int argc,
                 const char * const * argv );

private:

    /*!
      set team info by side and uniform number info
      this method is called at the last of analyzeInit().
    */
    virtual
    void initTeam();

protected:

    //! main decision
    virtual
    void doAction();

    //! communication decision
    virtual
    void doCommunication();


};

#endif

==> agent2d-0.2.0.tar.gz: agent2d-0.2.0/src/sample_player.h <==
// -*-c++-*-

/*
 *Copyright:

 Copyright (C) Hidehisa AKIYAMA

 This code is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This code is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this code; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *EndCopyright:
 */

/////////////////////////////////////////////////////////////////////

#ifndef AGENT2D_SAMPLE_PLAYER_H
#define AGENT2D__PLAYER_H

#include <rcsc/player/player_agent.h>

#include "strategy.h"

class SamplePlayer
    : public rcsc::PlayerAgent {
protected:
    Strategy M_strategy;

public:

    SamplePlayer();

    virtual
    ~SamplePlayer();

private:

    /*!
      set team info by side and uniform number info
      this method is called at the last of analyzeInit().
    */
    virtual
    void initTeam();

protected:

    /*!
      You can override this method.
      But you must call PlayerAgent::doInit() in this method.
    */
    virtual
    bool doInit( rcsc::CmdLineParser & cmd_parser );

    //! main decision
    virtual
    void doAction();

    //! communication decision
    virtual
    void doCommunication();


};

#endif
